==> kubernetes-model-storageclass-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/storage/VolumeAttachmentBuilder.java <==
package io.fabric8.kubernetes.api.model.storage;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class VolumeAttachmentBuilder extends VolumeAttachmentFluentImpl<VolumeAttachmentBuilder> implements VisitableBuilder<VolumeAttachment,VolumeAttachmentBuilder>{
  public VolumeAttachmentBuilder() {
    this(false);
  }
  public VolumeAttachmentBuilder(Boolean validationEnabled) {
    this(new VolumeAttachment(), validationEnabled);
  }
  public VolumeAttachmentBuilder(VolumeAttachmentFluent<?> fluent) {
    this(fluent, false);
  }
  public VolumeAttachmentBuilder(VolumeAttachmentFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new VolumeAttachment(), validationEnabled);
  }
  public VolumeAttachmentBuilder(VolumeAttachmentFluent<?> fluent,VolumeAttachment instance) {
    this(fluent, instance, false);
  }
  public VolumeAttachmentBuilder(VolumeAttachmentFluent<?> fluent,VolumeAttachment instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withSpec(instance.getSpec());
      fluent.withStatus(instance.getStatus());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public VolumeAttachmentBuilder(VolumeAttachment instance) {
    this(instance,false);
  }
  public VolumeAttachmentBuilder(VolumeAttachment instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  VolumeAttachmentFluent<?> fluent;
  Boolean validationEnabled;
  public VolumeAttachment build() {
    VolumeAttachment buildable = new VolumeAttachment(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> kubernetes-model-storageclass-6.8.1-sources.jar: io/fabric8/kubernetes/api/model/storage/VolumeAttachmentBuilder.java <==
package io.fabric8.kubernetes.api.model.storage;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class VolumeAttachmentBuilder extends VolumeAttachmentFluent<VolumeAttachmentBuilder> implements VisitableBuilder<VolumeAttachment,VolumeAttachmentBuilder>{
  public VolumeAttachmentBuilder() {
    this(false);
  }
  public VolumeAttachmentBuilder(Boolean validationEnabled) {
    this(new VolumeAttachment(), validationEnabled);
  }
  public VolumeAttachmentBuilder(VolumeAttachmentFluent<?> fluent) {
    this(fluent, false);
  }
  public VolumeAttachmentBuilder(VolumeAttachmentFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new VolumeAttachment(), validationEnabled);
  }
  public VolumeAttachmentBuilder(VolumeAttachmentFluent<?> fluent,VolumeAttachment instance) {
    this(fluent, instance, false);
  }
  public VolumeAttachmentBuilder(VolumeAttachmentFluent<?> fluent,VolumeAttachment instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new VolumeAttachment());

    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withSpec(instance.getSpec());
      fluent.withStatus(instance.getStatus());
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withSpec(instance.getSpec());
      fluent.withStatus(instance.getStatus());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public VolumeAttachmentBuilder(VolumeAttachment instance) {
    this(instance,false);
  }
  public VolumeAttachmentBuilder(VolumeAttachment instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new VolumeAttachment());

    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  VolumeAttachmentFluent<?> fluent;
  Boolean validationEnabled;
  public VolumeAttachment build() {
    VolumeAttachment buildable = new VolumeAttachment(fluent.getApiVersion(),fluent.getKind(),fluent.buildMetadata(),fluent.buildSpec(),fluent.buildStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
